netsurf: branch master updated. release/3.2-535-gfacaa0a
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/netsurf.git/shortlog/facaa0a8292091074ceaf...
...commit http://git.netsurf-browser.org/netsurf.git/commit/facaa0a8292091074ceaf35...
...tree http://git.netsurf-browser.org/netsurf.git/tree/facaa0a8292091074ceaf3558...
The branch, master has been updated
via facaa0a8292091074ceaf3558ea1b938e23ac213 (commit)
from 6684b938e24a4a11e45310ca2140b46c7c23a961 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/netsurf.git/commit/?id=facaa0a8292091074ce...
commit facaa0a8292091074ceaf3558ea1b938e23ac213
Author: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Commit: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Some OS3 compatibility for testing
diff --git a/amiga/Makefile.target b/amiga/Makefile.target
index 21a482d..5f7fe3f 100644
--- a/amiga/Makefile.target
+++ b/amiga/Makefile.target
@@ -72,7 +72,7 @@ S_AMIGA := gui.c tree.c history.c hotlist.c schedule.c file.c \
sslcert.c gui_options.c print.c theme.c drag.c icon.c libs.c \
datatypes.c dt_picture.c dt_anim.c dt_sound.c plugin_hack.c \
stringview/stringview.c stringview/urlhistory.c \
- agclass/amigaguide_class.c fs_backing_store.c
+ agclass/amigaguide_class.c fs_backing_store.c os3support.c
S_AMIGA := $(addprefix amiga/,$(S_AMIGA))
# This is the final source build list
diff --git a/amiga/iff_dr2d.c b/amiga/iff_dr2d.c
index 54929da..e8fd3e7 100644
--- a/amiga/iff_dr2d.c
+++ b/amiga/iff_dr2d.c
@@ -19,15 +19,18 @@
#ifdef WITH_NS_SVG
#include <stdio.h>
+#include <inttypes.h>
#include <svgtiny.h>
#include <proto/exec.h>
#include <string.h>
#include <proto/dos.h>
#ifndef AMIGA_DR2D_STANDALONE
+#include "amiga/os3support.h"
#include "amiga/iff_dr2d.h"
#include "content/hlcache.h"
#else
+#include "os3support.h"
#include "iff_dr2d.h"
#endif
@@ -68,7 +71,7 @@ static void addcolour(ULONG newcol)
}
bool ami_svg_to_dr2d(struct IFFHandle *iffh, const char *buffer,
- uint32 size, const char *url)
+ uint32_t size, const char *url)
{
struct svgtiny_diagram *diagram;
svgtiny_code code;
@@ -334,17 +337,19 @@ bool ami_save_svg(struct hlcache_handle *c,char *filename)
/*
* This code can be compiled as a standalone program for testing etc.
* Use something like the following line:
- * gcc -o svg2dr2d iff_dr2d.c -lauto -lsvgtiny -lpthread -lz -use-dynld
- * -DWITH_NS_SVG -DAMIGA_DR2D_STANDALONE -D__USE_INLINE__
+ * gcc -o svg2dr2d iff_dr2d.c -lauto -lsvgtiny -lpthread -lsvgtiny
+ * -ldom -lwapcaplet -lexpat -lparserutils
+ * -DWITH_NS_SVG -DAMIGA_DR2D_STANDALONE -D__USE_INLINE__ -D__NOLIBBASE__
*/
-const char USED ver[] = "\0$VER: svg2dr2d 1.1 (18.05.2009)\0";
+
+const char __attribute__((used)) ver[] = "\0$VER: svg2dr2d 1.1 (18.05.2009)\0";
int main(int argc, char **argv)
{
BPTR fh = 0;
char *buffer;
struct IFFHandle *iffh = NULL;
- int64 size;
+ int64_t size;
LONG rarray[] = {0,0};
struct RDArgs *args;
STRPTR template = "SVG=INPUT/A,DR2D=OUTPUT/A";
@@ -354,6 +359,14 @@ int main(int argc, char **argv)
A_DR2D
};
+#ifndef __amigaos4__
+ DOSBase = OpenLibrary("dos.library", 37);
+ if(!DOSBase) return RETURN_FAIL;
+
+ IFFParseBase = OpenLibrary("iffparse.library", 37);
+ if(!IFFParseBase) return RETURN_FAIL;
+#endif
+
args = ReadArgs(template,rarray,NULL);
if(!args)
@@ -366,9 +379,9 @@ int main(int argc, char **argv)
{
size = GetFileSize(fh);
- buffer = AllocVecTagList((uint32)size, NULL);
+ buffer = AllocVecTagList((uint32_t)size, NULL);
- Read(fh,buffer,(uint32)size);
+ Read(fh,buffer,(uint32_t)size);
Close(fh);
}
else
@@ -395,7 +408,13 @@ int main(int argc, char **argv)
if(iffh->iff_Stream) Close((BPTR)iffh->iff_Stream);
if(iffh) FreeIFF(iffh);
FreeArgs(args);
+
+#ifndef __amigaos4__
+ if(DOSBase) CloseLibrary(DOSBase);
+ if(IFFParseBase) CloseLibrary(IFFParseBase);
+#endif
}
#endif // AMIGA_DR2D_STANDALONE
#endif // WITH_NS_SVG
+
diff --git a/amiga/iff_dr2d.h b/amiga/iff_dr2d.h
index 7ef5622..c9981d3 100644
--- a/amiga/iff_dr2d.h
+++ b/amiga/iff_dr2d.h
@@ -66,7 +66,7 @@ struct stxt_struct {
float CharW, CharH, /* W/H of an individual char */
BaseX, BaseY, /* Start of baseline */
Rotation; /* Angle of text (in degrees) */
- uint16 NumChars;
+ uint16_t NumChars;
//char TextChars[NumChars];
};
@@ -99,7 +99,7 @@ struct dash_struct {
};
bool ami_svg_to_dr2d(struct IFFHandle *iffh, const char *buffer,
- uint32 size, const char *url);
+ uint32_t size, const char *url);
#ifndef AMIGA_DR2D_STANDALONE
bool ami_save_svg(struct hlcache_handle *c, char *filename);
#endif
diff --git a/amiga/os3support.c b/amiga/os3support.c
new file mode 100644
index 0000000..b9134ac
--- /dev/null
+++ b/amiga/os3support.c
@@ -0,0 +1,39 @@
+/*
+ * Copyright 2014 Chris Young <chris(a)unsatisfactorysoftware.co.uk>
+ *
+ * This file is part of NetSurf, http://www.netsurf-browser.org/
+ *
+ * NetSurf is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * NetSurf is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
+
+/** \file
+ * Minimal compatibility header for AmigaOS 3
+ */
+
+#ifndef __amigaos4__
+#include "os3support.h"
+
+int64 GetFileSize(BPTR fh)
+{
+ int32 size = 0;
+ struct FileInfoBlock *fib = AllocVec(sizeof(struct FileInfoBlock), MEMF_ANY);
+ if(fib == NULL) return 0;
+
+ ExamineFH(fh, fib);
+ size = fib->fib_Size;
+
+ FreeVec(fib);
+ return (int64)size;
+}
+
+#endif
diff --git a/amiga/os3support.h b/amiga/os3support.h
index c93e09a..61b6d06 100644
--- a/amiga/os3support.h
+++ b/amiga/os3support.h
@@ -26,6 +26,8 @@
#ifndef __amigaos4__
#include <stdint.h>
+#include <proto/exec.h>
+#include <proto/dos.h>
/* Include prototypes for amigalib */
#include <clib/alib_protos.h>
@@ -34,10 +36,18 @@
#include <exec/memory.h>
#endif
+/* Library bases */
+struct Library *SysBase;
+struct Library *DOSBase;
+struct Library *IFFParseBase;
+
/* Define extra memory type flags */
#define MEMF_PRIVATE MEMF_ANY
#define MEMF_SHARED MEMF_ANY
+/* Easy wrapper for AllocVecTagList with no tags */
+#define AllocVecTagList(SZ,TAG) AllocVec(SZ,MEMF_ANY);
+
/* Integral type definitions */
typedef int8_t int8;
typedef uint8_t uint8;
@@ -45,6 +55,8 @@ typedef int16_t int16;
typedef uint16_t uint16;
typedef int32_t int32;
typedef uint32_t uint32;
+typedef int64_t int64;
+typedef uint64_t uint64;
/* TimeVal */
struct TimeVal {
@@ -79,6 +91,8 @@ struct TimeVal {
#define IDFMT_PALETTEMAPPED (1) /* Palette mapped icon (chunky, V44+) */
#define IDFMT_DIRECTMAPPED (2) /* Direct mapped icon (truecolor 0xAARRGGBB, V51+) */
+/* Functions */
+int64 GetFileSize(BPTR fh);
#endif
#endif
-----------------------------------------------------------------------
Summary of changes:
amiga/Makefile.target | 2 +-
amiga/iff_dr2d.c | 33 ++++++++++++++++++++++------
amiga/iff_dr2d.h | 4 ++--
amiga/{fs_backing_store.h => os3support.c} | 24 ++++++++++++++++----
amiga/os3support.h | 14 ++++++++++++
5 files changed, 63 insertions(+), 14 deletions(-)
copy amiga/{fs_backing_store.h => os3support.c} (68%)
diff --git a/amiga/Makefile.target b/amiga/Makefile.target
index 21a482d..5f7fe3f 100644
--- a/amiga/Makefile.target
+++ b/amiga/Makefile.target
@@ -72,7 +72,7 @@ S_AMIGA := gui.c tree.c history.c hotlist.c schedule.c file.c \
sslcert.c gui_options.c print.c theme.c drag.c icon.c libs.c \
datatypes.c dt_picture.c dt_anim.c dt_sound.c plugin_hack.c \
stringview/stringview.c stringview/urlhistory.c \
- agclass/amigaguide_class.c fs_backing_store.c
+ agclass/amigaguide_class.c fs_backing_store.c os3support.c
S_AMIGA := $(addprefix amiga/,$(S_AMIGA))
# This is the final source build list
diff --git a/amiga/iff_dr2d.c b/amiga/iff_dr2d.c
index 54929da..e8fd3e7 100644
--- a/amiga/iff_dr2d.c
+++ b/amiga/iff_dr2d.c
@@ -19,15 +19,18 @@
#ifdef WITH_NS_SVG
#include <stdio.h>
+#include <inttypes.h>
#include <svgtiny.h>
#include <proto/exec.h>
#include <string.h>
#include <proto/dos.h>
#ifndef AMIGA_DR2D_STANDALONE
+#include "amiga/os3support.h"
#include "amiga/iff_dr2d.h"
#include "content/hlcache.h"
#else
+#include "os3support.h"
#include "iff_dr2d.h"
#endif
@@ -68,7 +71,7 @@ static void addcolour(ULONG newcol)
}
bool ami_svg_to_dr2d(struct IFFHandle *iffh, const char *buffer,
- uint32 size, const char *url)
+ uint32_t size, const char *url)
{
struct svgtiny_diagram *diagram;
svgtiny_code code;
@@ -334,17 +337,19 @@ bool ami_save_svg(struct hlcache_handle *c,char *filename)
/*
* This code can be compiled as a standalone program for testing etc.
* Use something like the following line:
- * gcc -o svg2dr2d iff_dr2d.c -lauto -lsvgtiny -lpthread -lz -use-dynld
- * -DWITH_NS_SVG -DAMIGA_DR2D_STANDALONE -D__USE_INLINE__
+ * gcc -o svg2dr2d iff_dr2d.c -lauto -lsvgtiny -lpthread -lsvgtiny
+ * -ldom -lwapcaplet -lexpat -lparserutils
+ * -DWITH_NS_SVG -DAMIGA_DR2D_STANDALONE -D__USE_INLINE__ -D__NOLIBBASE__
*/
-const char USED ver[] = "\0$VER: svg2dr2d 1.1 (18.05.2009)\0";
+
+const char __attribute__((used)) ver[] = "\0$VER: svg2dr2d 1.1 (18.05.2009)\0";
int main(int argc, char **argv)
{
BPTR fh = 0;
char *buffer;
struct IFFHandle *iffh = NULL;
- int64 size;
+ int64_t size;
LONG rarray[] = {0,0};
struct RDArgs *args;
STRPTR template = "SVG=INPUT/A,DR2D=OUTPUT/A";
@@ -354,6 +359,14 @@ int main(int argc, char **argv)
A_DR2D
};
+#ifndef __amigaos4__
+ DOSBase = OpenLibrary("dos.library", 37);
+ if(!DOSBase) return RETURN_FAIL;
+
+ IFFParseBase = OpenLibrary("iffparse.library", 37);
+ if(!IFFParseBase) return RETURN_FAIL;
+#endif
+
args = ReadArgs(template,rarray,NULL);
if(!args)
@@ -366,9 +379,9 @@ int main(int argc, char **argv)
{
size = GetFileSize(fh);
- buffer = AllocVecTagList((uint32)size, NULL);
+ buffer = AllocVecTagList((uint32_t)size, NULL);
- Read(fh,buffer,(uint32)size);
+ Read(fh,buffer,(uint32_t)size);
Close(fh);
}
else
@@ -395,7 +408,13 @@ int main(int argc, char **argv)
if(iffh->iff_Stream) Close((BPTR)iffh->iff_Stream);
if(iffh) FreeIFF(iffh);
FreeArgs(args);
+
+#ifndef __amigaos4__
+ if(DOSBase) CloseLibrary(DOSBase);
+ if(IFFParseBase) CloseLibrary(IFFParseBase);
+#endif
}
#endif // AMIGA_DR2D_STANDALONE
#endif // WITH_NS_SVG
+
diff --git a/amiga/iff_dr2d.h b/amiga/iff_dr2d.h
index 7ef5622..c9981d3 100644
--- a/amiga/iff_dr2d.h
+++ b/amiga/iff_dr2d.h
@@ -66,7 +66,7 @@ struct stxt_struct {
float CharW, CharH, /* W/H of an individual char */
BaseX, BaseY, /* Start of baseline */
Rotation; /* Angle of text (in degrees) */
- uint16 NumChars;
+ uint16_t NumChars;
//char TextChars[NumChars];
};
@@ -99,7 +99,7 @@ struct dash_struct {
};
bool ami_svg_to_dr2d(struct IFFHandle *iffh, const char *buffer,
- uint32 size, const char *url);
+ uint32_t size, const char *url);
#ifndef AMIGA_DR2D_STANDALONE
bool ami_save_svg(struct hlcache_handle *c, char *filename);
#endif
diff --git a/amiga/fs_backing_store.h b/amiga/os3support.c
similarity index 68%
copy from amiga/fs_backing_store.h
copy to amiga/os3support.c
index 89a67fb..b9134ac 100644
--- a/amiga/fs_backing_store.h
+++ b/amiga/os3support.c
@@ -16,8 +16,24 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef AMIGA_FS_BACKING_STORE_H
-#define AMIGA_FS_BACKING_STORE_H
-extern struct gui_llcache_table *amiga_filesystem_llcache_table;
-#endif
+/** \file
+ * Minimal compatibility header for AmigaOS 3
+ */
+
+#ifndef __amigaos4__
+#include "os3support.h"
+
+int64 GetFileSize(BPTR fh)
+{
+ int32 size = 0;
+ struct FileInfoBlock *fib = AllocVec(sizeof(struct FileInfoBlock), MEMF_ANY);
+ if(fib == NULL) return 0;
+ ExamineFH(fh, fib);
+ size = fib->fib_Size;
+
+ FreeVec(fib);
+ return (int64)size;
+}
+
+#endif
diff --git a/amiga/os3support.h b/amiga/os3support.h
index c93e09a..61b6d06 100644
--- a/amiga/os3support.h
+++ b/amiga/os3support.h
@@ -26,6 +26,8 @@
#ifndef __amigaos4__
#include <stdint.h>
+#include <proto/exec.h>
+#include <proto/dos.h>
/* Include prototypes for amigalib */
#include <clib/alib_protos.h>
@@ -34,10 +36,18 @@
#include <exec/memory.h>
#endif
+/* Library bases */
+struct Library *SysBase;
+struct Library *DOSBase;
+struct Library *IFFParseBase;
+
/* Define extra memory type flags */
#define MEMF_PRIVATE MEMF_ANY
#define MEMF_SHARED MEMF_ANY
+/* Easy wrapper for AllocVecTagList with no tags */
+#define AllocVecTagList(SZ,TAG) AllocVec(SZ,MEMF_ANY);
+
/* Integral type definitions */
typedef int8_t int8;
typedef uint8_t uint8;
@@ -45,6 +55,8 @@ typedef int16_t int16;
typedef uint16_t uint16;
typedef int32_t int32;
typedef uint32_t uint32;
+typedef int64_t int64;
+typedef uint64_t uint64;
/* TimeVal */
struct TimeVal {
@@ -79,6 +91,8 @@ struct TimeVal {
#define IDFMT_PALETTEMAPPED (1) /* Palette mapped icon (chunky, V44+) */
#define IDFMT_DIRECTMAPPED (2) /* Direct mapped icon (truecolor 0xAARRGGBB, V51+) */
+/* Functions */
+int64 GetFileSize(BPTR fh);
#endif
#endif
--
NetSurf Browser
8 years, 5 months
libnsutils: branch master updated. 62f1e9f6653037cf787d03af0370a7c822b41b30
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/libnsutils.git/shortlog/62f1e9f6653037cf78...
...commit http://git.netsurf-browser.org/libnsutils.git/commit/62f1e9f6653037cf787d...
...tree http://git.netsurf-browser.org/libnsutils.git/tree/62f1e9f6653037cf787d03...
The branch, master has been updated
via 62f1e9f6653037cf787d03af0370a7c822b41b30 (commit)
from 4fc947676f34bb8157afaf0038c042ebcca16b1c (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/libnsutils.git/commit/?id=62f1e9f6653037cf...
commit 62f1e9f6653037cf787d03af0370a7c822b41b30
Author: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Commit: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Fix build on m68k amigaos
diff --git a/src/time.c b/src/time.c
index 94139c3..1f79857 100644
--- a/src/time.c
+++ b/src/time.c
@@ -63,7 +63,7 @@ nsuerror nsu_getmonotonic_ms(uint64_t *current_out)
#elif defined(__amiga)
struct EClockVal eclockval;
int freq = 0;
- uint64 eclock;
+ uint64_t eclock;
/* NB: The calling task must already have opened timer.device
* and obtained the interface.
@@ -74,7 +74,7 @@ nsuerror nsu_getmonotonic_ms(uint64_t *current_out)
#endif
freq = ReadEClock(&eclockval) / 1000;
- eclock = ((uint64)eclockval.ev_hi << 32) | (eclockval.ev_lo);
+ eclock = ((uint64_t)eclockval.ev_hi << 32) | (eclockval.ev_lo);
current = eclock / freq;
#else
#warning "Using dodgy gettimeofday() fallback"
-----------------------------------------------------------------------
Summary of changes:
src/time.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/src/time.c b/src/time.c
index 94139c3..1f79857 100644
--- a/src/time.c
+++ b/src/time.c
@@ -63,7 +63,7 @@ nsuerror nsu_getmonotonic_ms(uint64_t *current_out)
#elif defined(__amiga)
struct EClockVal eclockval;
int freq = 0;
- uint64 eclock;
+ uint64_t eclock;
/* NB: The calling task must already have opened timer.device
* and obtained the interface.
@@ -74,7 +74,7 @@ nsuerror nsu_getmonotonic_ms(uint64_t *current_out)
#endif
freq = ReadEClock(&eclockval) / 1000;
- eclock = ((uint64)eclockval.ev_hi << 32) | (eclockval.ev_lo);
+ eclock = ((uint64_t)eclockval.ev_hi << 32) | (eclockval.ev_lo);
current = eclock / freq;
#else
#warning "Using dodgy gettimeofday() fallback"
--
NetSurf generalised utility library
8 years, 5 months
toolchains: branch master updated. 488befc4e4a21ef6bb2347cae0148002221e965f
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/toolchains.git/shortlog/488befc4e4a21ef6bb...
...commit http://git.netsurf-browser.org/toolchains.git/commit/488befc4e4a21ef6bb23...
...tree http://git.netsurf-browser.org/toolchains.git/tree/488befc4e4a21ef6bb2347...
The branch, master has been updated
via 488befc4e4a21ef6bb2347cae0148002221e965f (commit)
from 8a361ac4bd1b3d5d643b7eb18fe86aa5ef53a079 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/toolchains.git/commit/?id=488befc4e4a21ef6...
commit 488befc4e4a21ef6bb2347cae0148002221e965f
Author: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Commit: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
clib2 doesn't have malloc.h and libpbl doesn't appear to need it with newlib either.
diff --git a/sdk/recipes/patches/libpbl/no-malloc.h.p b/sdk/recipes/patches/libpbl/no-malloc.h.p
new file mode 100644
index 0000000..f73f7b4
--- /dev/null
+++ b/sdk/recipes/patches/libpbl/no-malloc.h.p
@@ -0,0 +1,154 @@
+--- src/pbl.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pbl.c 2014-12-19 18:53:46.340018151 +0000
+@@ -51,7 +51,7 @@ char* pbl_c_id = "$Id: pbl.c,v 1.15 2010
+ #include <string.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblCollection.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblCollection.c 2014-12-19 18:53:05.372018271 +0000
+@@ -45,7 +45,7 @@ char* pblCollection_c_id = "$Id: pblColl
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblhash.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblhash.c 2014-12-19 18:52:56.652018298 +0000
+@@ -66,7 +66,7 @@ char* pblhash_c_id = "$Id: pblhash.c,v 1
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblHeap.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblHeap.c 2014-12-19 18:53:14.144018245 +0000
+@@ -38,7 +38,7 @@ char* pblHeap_c_id = "$Id: pblHeap.c,v 1
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblhttst.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblhttst.c 2014-12-19 18:52:47.260018324 +0000
+@@ -56,7 +56,7 @@ char* pblhttst_c_id = "$Id: pblhttst.c,v
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblIterator.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblIterator.c 2014-12-19 18:53:22.556018222 +0000
+@@ -50,7 +50,7 @@ char * PblIteratorMagic = "PblIteratorMa
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblList.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblList.c 2014-12-19 18:54:17.436018060 +0000
+@@ -54,7 +54,7 @@ char * PblLinkedListMagic = "PblLinkedLi
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblMap.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblMap.c 2014-12-19 18:53:54.336018129 +0000
+@@ -56,7 +56,7 @@ char* pblMap_c_id = "$Id: pblMap.c,v 1.7
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblMapTest.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblMapTest.c 2014-12-19 18:52:28.496018379 +0000
+@@ -48,7 +48,7 @@ char* pblMapTest_c_id =
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblPerform.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblPerform.c 2014-12-19 18:53:35.700018182 +0000
+@@ -60,7 +60,7 @@ char* pblPerform_c_id =
+ #include <memory.h>
+ #include <sys/time.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblPriorityQueue.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblPriorityQueue.c 2014-12-19 18:54:14.628018068 +0000
+@@ -45,7 +45,7 @@ char* pblPriorityQueue_c_id =
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblPriorityQueueTest.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblPriorityQueueTest.c 2014-12-19 18:52:37.076018355 +0000
+@@ -45,7 +45,7 @@ char* pblPriorityQueueTest_c_id =
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblSet.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblSet.c 2014-12-19 18:52:19.716018406 +0000
+@@ -64,7 +64,7 @@ char * PblTreeSetMagic = "PblTreeSetMagi
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pbltest.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pbltest.c 2014-12-19 18:51:55.048018477 +0000
+@@ -57,7 +57,7 @@ char* pbltest_c_id = "$Id: pbltest.c,v 1
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
-----------------------------------------------------------------------
Summary of changes:
sdk/recipes/patches/libpbl/no-malloc.h.p | 154 ++++++++++++++++++++++++++++++
1 file changed, 154 insertions(+)
create mode 100644 sdk/recipes/patches/libpbl/no-malloc.h.p
diff --git a/sdk/recipes/patches/libpbl/no-malloc.h.p b/sdk/recipes/patches/libpbl/no-malloc.h.p
new file mode 100644
index 0000000..f73f7b4
--- /dev/null
+++ b/sdk/recipes/patches/libpbl/no-malloc.h.p
@@ -0,0 +1,154 @@
+--- src/pbl.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pbl.c 2014-12-19 18:53:46.340018151 +0000
+@@ -51,7 +51,7 @@ char* pbl_c_id = "$Id: pbl.c,v 1.15 2010
+ #include <string.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblCollection.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblCollection.c 2014-12-19 18:53:05.372018271 +0000
+@@ -45,7 +45,7 @@ char* pblCollection_c_id = "$Id: pblColl
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblhash.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblhash.c 2014-12-19 18:52:56.652018298 +0000
+@@ -66,7 +66,7 @@ char* pblhash_c_id = "$Id: pblhash.c,v 1
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblHeap.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblHeap.c 2014-12-19 18:53:14.144018245 +0000
+@@ -38,7 +38,7 @@ char* pblHeap_c_id = "$Id: pblHeap.c,v 1
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblhttst.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblhttst.c 2014-12-19 18:52:47.260018324 +0000
+@@ -56,7 +56,7 @@ char* pblhttst_c_id = "$Id: pblhttst.c,v
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblIterator.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblIterator.c 2014-12-19 18:53:22.556018222 +0000
+@@ -50,7 +50,7 @@ char * PblIteratorMagic = "PblIteratorMa
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblList.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblList.c 2014-12-19 18:54:17.436018060 +0000
+@@ -54,7 +54,7 @@ char * PblLinkedListMagic = "PblLinkedLi
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblMap.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblMap.c 2014-12-19 18:53:54.336018129 +0000
+@@ -56,7 +56,7 @@ char* pblMap_c_id = "$Id: pblMap.c,v 1.7
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblMapTest.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblMapTest.c 2014-12-19 18:52:28.496018379 +0000
+@@ -48,7 +48,7 @@ char* pblMapTest_c_id =
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblPerform.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblPerform.c 2014-12-19 18:53:35.700018182 +0000
+@@ -60,7 +60,7 @@ char* pblPerform_c_id =
+ #include <memory.h>
+ #include <sys/time.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblPriorityQueue.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblPriorityQueue.c 2014-12-19 18:54:14.628018068 +0000
+@@ -45,7 +45,7 @@ char* pblPriorityQueue_c_id =
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblPriorityQueueTest.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblPriorityQueueTest.c 2014-12-19 18:52:37.076018355 +0000
+@@ -45,7 +45,7 @@ char* pblPriorityQueueTest_c_id =
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pblSet.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pblSet.c 2014-12-19 18:52:19.716018406 +0000
+@@ -64,7 +64,7 @@ char * PblTreeSetMagic = "PblTreeSetMagi
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
+--- src/pbltest.c 2010-10-18 22:45:22.000000000 +0100
++++ src/pbltest.c 2014-12-19 18:51:55.048018477 +0000
+@@ -57,7 +57,7 @@ char* pbltest_c_id = "$Id: pbltest.c,v 1
+ #include <stdio.h>
+ #include <memory.h>
+
+-#ifndef __APPLE__
++#if !defined(__APPLE__) && !defined(AMIGA)
+ #include <malloc.h>
+ #endif
+
--
Cross-compilation toolchains and environments
8 years, 5 months
netsurf: branch master updated. release/3.2-534-g6684b93
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/netsurf.git/shortlog/6684b938e24a4a11e4531...
...commit http://git.netsurf-browser.org/netsurf.git/commit/6684b938e24a4a11e45310c...
...tree http://git.netsurf-browser.org/netsurf.git/tree/6684b938e24a4a11e45310ca2...
The branch, master has been updated
via 6684b938e24a4a11e45310ca2140b46c7c23a961 (commit)
from 876b6cbeb0eaf718f17bdbadf37182cb72730d81 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/netsurf.git/commit/?id=6684b938e24a4a11e45...
commit 6684b938e24a4a11e45310ca2140b46c7c23a961
Author: Vincent Sanders <vince(a)kyllikki.org>
Commit: Vincent Sanders <vince(a)kyllikki.org>
Update the coverity build script for buildsystem HOST/BUILD changes
diff --git a/utils/coverity-build.sh b/utils/coverity-build.sh
index 8bd9011..b7174cf 100755
--- a/utils/coverity-build.sh
+++ b/utils/coverity-build.sh
@@ -27,10 +27,10 @@
# environment variables
#
+# HOST The ABI to be compiled for
# COVERITY_TOKEN
# COVERITY_USER
# COVERITY_PREFIX path to tools else default is used
-# BUILD
#
# either PREFIX or JENKINS_HOME
@@ -38,13 +38,13 @@
TARGETS="gtk framebuffer monkey"
# setup build environment
-export PREFIX=${PREFIX:-${JENKINS_HOME}/artifacts-${BUILD}}
+export PREFIX=${PREFIX:-${JENKINS_HOME}/artifacts-${HOST}}
export PKG_CONFIG_PATH=${PREFIX}/lib/pkgconfig
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${PREFIX}/lib
export PATH=${PATH}:${PREFIX}/bin
# Coverity tools location
-COVERITY_PREFIX=${COVERITY_PREFIX:-/opt/coverity/cov-analysis-linux64-7.0.2}
+COVERITY_PREFIX=${COVERITY_PREFIX:-/opt/coverity/cov-analysis-linux64-7.5.0}
COVERITY_VERSION=$(git rev-parse HEAD)
export PATH=${PATH}:${COVERITY_PREFIX}/bin
-----------------------------------------------------------------------
Summary of changes:
utils/coverity-build.sh | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/utils/coverity-build.sh b/utils/coverity-build.sh
index 8bd9011..b7174cf 100755
--- a/utils/coverity-build.sh
+++ b/utils/coverity-build.sh
@@ -27,10 +27,10 @@
# environment variables
#
+# HOST The ABI to be compiled for
# COVERITY_TOKEN
# COVERITY_USER
# COVERITY_PREFIX path to tools else default is used
-# BUILD
#
# either PREFIX or JENKINS_HOME
@@ -38,13 +38,13 @@
TARGETS="gtk framebuffer monkey"
# setup build environment
-export PREFIX=${PREFIX:-${JENKINS_HOME}/artifacts-${BUILD}}
+export PREFIX=${PREFIX:-${JENKINS_HOME}/artifacts-${HOST}}
export PKG_CONFIG_PATH=${PREFIX}/lib/pkgconfig
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${PREFIX}/lib
export PATH=${PATH}:${PREFIX}/bin
# Coverity tools location
-COVERITY_PREFIX=${COVERITY_PREFIX:-/opt/coverity/cov-analysis-linux64-7.0.2}
+COVERITY_PREFIX=${COVERITY_PREFIX:-/opt/coverity/cov-analysis-linux64-7.5.0}
COVERITY_VERSION=$(git rev-parse HEAD)
export PATH=${PATH}:${COVERITY_PREFIX}/bin
--
NetSurf Browser
8 years, 5 months
toolchains: branch master updated. 8a361ac4bd1b3d5d643b7eb18fe86aa5ef53a079
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/toolchains.git/shortlog/8a361ac4bd1b3d5d64...
...commit http://git.netsurf-browser.org/toolchains.git/commit/8a361ac4bd1b3d5d643b...
...tree http://git.netsurf-browser.org/toolchains.git/tree/8a361ac4bd1b3d5d643b7e...
The branch, master has been updated
via 8a361ac4bd1b3d5d643b7eb18fe86aa5ef53a079 (commit)
from 110cc76ad1289310bf8c57183917b0ad58abf6d6 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/toolchains.git/commit/?id=8a361ac4bd1b3d5d...
commit 8a361ac4bd1b3d5d643b7eb18fe86aa5ef53a079
Author: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Commit: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Fix libiconv m68k-amigaos build
diff --git a/sdk/Makefile b/sdk/Makefile
index 1de8dc0..8d02603 100644
--- a/sdk/Makefile
+++ b/sdk/Makefile
@@ -126,7 +126,7 @@ ifeq ($(TARGET),i686-w64-mingw32)
endif
ifeq ($(TARGET),m68k-unknown-amigaos)
- SDK_ITEMS := $(addprefix $(BUILDSTEPS)/, libiconv.d libtre.d $(COMMON_SDK_ITEMS))
+ SDK_ITEMS := $(addprefix $(BUILDSTEPS)/, libiconv.d libtre.d libpbl.d $(COMMON_SDK_ITEMS))
EXTRAARGS_LIBCARES := --disable-shared --without-random
endif
diff --git a/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.signal.in.h.p b/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.signal.in.h.p
new file mode 100644
index 0000000..93ee6a9
--- /dev/null
+++ b/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.signal.in.h.p
@@ -0,0 +1,72 @@
+--- srclib/signal.in.h.orig 2011-08-07 14:42:06.000000000 +0100
++++ srclib/signal.in.h 2014-01-15 00:57:27.620548058 +0000
+@@ -168,69 +168,6 @@
+
+ # endif
+
+-/* Test whether a given signal is contained in a signal set. */
+-# if @HAVE_POSIX_SIGNALBLOCKING@
+-/* This function is defined as a macro on MacOS X. */
+-# if defined __cplusplus && defined GNULIB_NAMESPACE
+-# undef sigismember
+-# endif
+-# else
+-_GL_FUNCDECL_SYS (sigismember, int, (const sigset_t *set, int sig)
+- _GL_ARG_NONNULL ((1)));
+-# endif
+-_GL_CXXALIAS_SYS (sigismember, int, (const sigset_t *set, int sig));
+-_GL_CXXALIASWARN (sigismember);
+-
+-/* Initialize a signal set to the empty set. */
+-# if @HAVE_POSIX_SIGNALBLOCKING@
+-/* This function is defined as a macro on MacOS X. */
+-# if defined __cplusplus && defined GNULIB_NAMESPACE
+-# undef sigemptyset
+-# endif
+-# else
+-_GL_FUNCDECL_SYS (sigemptyset, int, (sigset_t *set) _GL_ARG_NONNULL ((1)));
+-# endif
+-_GL_CXXALIAS_SYS (sigemptyset, int, (sigset_t *set));
+-_GL_CXXALIASWARN (sigemptyset);
+-
+-/* Add a signal to a signal set. */
+-# if @HAVE_POSIX_SIGNALBLOCKING@
+-/* This function is defined as a macro on MacOS X. */
+-# if defined __cplusplus && defined GNULIB_NAMESPACE
+-# undef sigaddset
+-# endif
+-# else
+-_GL_FUNCDECL_SYS (sigaddset, int, (sigset_t *set, int sig)
+- _GL_ARG_NONNULL ((1)));
+-# endif
+-_GL_CXXALIAS_SYS (sigaddset, int, (sigset_t *set, int sig));
+-_GL_CXXALIASWARN (sigaddset);
+-
+-/* Remove a signal from a signal set. */
+-# if @HAVE_POSIX_SIGNALBLOCKING@
+-/* This function is defined as a macro on MacOS X. */
+-# if defined __cplusplus && defined GNULIB_NAMESPACE
+-# undef sigdelset
+-# endif
+-# else
+-_GL_FUNCDECL_SYS (sigdelset, int, (sigset_t *set, int sig)
+- _GL_ARG_NONNULL ((1)));
+-# endif
+-_GL_CXXALIAS_SYS (sigdelset, int, (sigset_t *set, int sig));
+-_GL_CXXALIASWARN (sigdelset);
+-
+-/* Fill a signal set with all possible signals. */
+-# if @HAVE_POSIX_SIGNALBLOCKING@
+-/* This function is defined as a macro on MacOS X. */
+-# if defined __cplusplus && defined GNULIB_NAMESPACE
+-# undef sigfillset
+-# endif
+-# else
+-_GL_FUNCDECL_SYS (sigfillset, int, (sigset_t *set) _GL_ARG_NONNULL ((1)));
+-# endif
+-_GL_CXXALIAS_SYS (sigfillset, int, (sigset_t *set));
+-_GL_CXXALIASWARN (sigfillset);
+-
+ /* Return the set of those blocked signals that are pending. */
+ # if !@HAVE_POSIX_SIGNALBLOCKING@
+ _GL_FUNCDECL_SYS (sigpending, int, (sigset_t *set) _GL_ARG_NONNULL ((1)));
diff --git a/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.sigprocmask.c.p b/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.sigprocmask.c.p
new file mode 100644
index 0000000..a811881
--- /dev/null
+++ b/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.sigprocmask.c.p
@@ -0,0 +1,80 @@
+--- srclib/sigprocmask.c.orig 2011-08-07 14:42:06.000000000 +0100
++++ srclib/sigprocmask.c 2014-01-15 00:59:33.130968152 +0000
+@@ -83,77 +83,6 @@
+ # define signal ext_signal
+ #endif
+
+-int
+-sigismember (const sigset_t *set, int sig)
+-{
+- if (sig >= 0 && sig < NSIG)
+- {
+- #ifdef SIGABRT_COMPAT
+- if (sig == SIGABRT_COMPAT)
+- sig = SIGABRT;
+- #endif
+-
+- return (*set >> sig) & 1;
+- }
+- else
+- return 0;
+-}
+-
+-int
+-sigemptyset (sigset_t *set)
+-{
+- *set = 0;
+- return 0;
+-}
+-
+-int
+-sigaddset (sigset_t *set, int sig)
+-{
+- if (sig >= 0 && sig < NSIG)
+- {
+- #ifdef SIGABRT_COMPAT
+- if (sig == SIGABRT_COMPAT)
+- sig = SIGABRT;
+- #endif
+-
+- *set |= 1U << sig;
+- return 0;
+- }
+- else
+- {
+- errno = EINVAL;
+- return -1;
+- }
+-}
+-
+-int
+-sigdelset (sigset_t *set, int sig)
+-{
+- if (sig >= 0 && sig < NSIG)
+- {
+- #ifdef SIGABRT_COMPAT
+- if (sig == SIGABRT_COMPAT)
+- sig = SIGABRT;
+- #endif
+-
+- *set &= ~(1U << sig);
+- return 0;
+- }
+- else
+- {
+- errno = EINVAL;
+- return -1;
+- }
+-}
+-
+-
+-int
+-sigfillset (sigset_t *set)
+-{
+- *set = ((2U << (NSIG - 1)) - 1) & ~ SIGABRT_COMPAT_MASK;
+- return 0;
+-}
+-
+ /* Set of currently blocked signals. */
+ static volatile sigset_t blocked_set /* = 0 */;
+
diff --git a/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.unistd.in.h.p b/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.unistd.in.h.p
new file mode 100644
index 0000000..eecac92
--- /dev/null
+++ b/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.unistd.in.h.p
@@ -0,0 +1,43 @@
+--- srclib/unistd.in.h.orig 2014-01-15 01:06:20.525844246 +0000
++++ srclib/unistd.in.h 2014-01-15 01:06:48.717471325 +0000
+@@ -1145,40 +1145,6 @@
+ #endif
+
+
+-#if @GNULIB_READLINK@
+-/* Read the contents of the symbolic link FILE and place the first BUFSIZE
+- bytes of it into BUF. Return the number of bytes placed into BUF if
+- successful, otherwise -1 and errno set.
+- See the POSIX:2001 specification
+- <http://www.opengroup.org/susv3xsh/readlink.html>. */
+-# if @REPLACE_READLINK@
+-# if !(defined __cplusplus && defined GNULIB_NAMESPACE)
+-# define readlink rpl_readlink
+-# endif
+-_GL_FUNCDECL_RPL (readlink, ssize_t,
+- (const char *file, char *buf, size_t bufsize)
+- _GL_ARG_NONNULL ((1, 2)));
+-_GL_CXXALIAS_RPL (readlink, ssize_t,
+- (const char *file, char *buf, size_t bufsize));
+-# else
+-# if !@HAVE_READLINK@
+-_GL_FUNCDECL_SYS (readlink, ssize_t,
+- (const char *file, char *buf, size_t bufsize)
+- _GL_ARG_NONNULL ((1, 2)));
+-# endif
+-_GL_CXXALIAS_SYS (readlink, ssize_t,
+- (const char *file, char *buf, size_t bufsize));
+-# endif
+-_GL_CXXALIASWARN (readlink);
+-#elif defined GNULIB_POSIXCHECK
+-# undef readlink
+-# if HAVE_RAW_DECL_READLINK
+-_GL_WARN_ON_USE (readlink, "readlink is unportable - "
+- "use gnulib module readlink for portability");
+-# endif
+-#endif
+-
+-
+ #if @GNULIB_READLINKAT@
+ # if !@HAVE_READLINKAT@
+ _GL_FUNCDECL_SYS (readlinkat, ssize_t,
-----------------------------------------------------------------------
Summary of changes:
sdk/Makefile | 2 +-
.../{ppc-amigaos => m68k-unknown-amigaos}/srclib.signal.in.h.p | 0
.../{ppc-amigaos => m68k-unknown-amigaos}/srclib.sigprocmask.c.p | 0
.../{ppc-amigaos => m68k-unknown-amigaos}/srclib.unistd.in.h.p | 0
4 files changed, 1 insertion(+), 1 deletion(-)
copy sdk/recipes/patches/libiconv/{ppc-amigaos => m68k-unknown-amigaos}/srclib.signal.in.h.p (100%)
copy sdk/recipes/patches/libiconv/{ppc-amigaos => m68k-unknown-amigaos}/srclib.sigprocmask.c.p (100%)
copy sdk/recipes/patches/libiconv/{ppc-amigaos => m68k-unknown-amigaos}/srclib.unistd.in.h.p (100%)
diff --git a/sdk/Makefile b/sdk/Makefile
index 1de8dc0..8d02603 100644
--- a/sdk/Makefile
+++ b/sdk/Makefile
@@ -126,7 +126,7 @@ ifeq ($(TARGET),i686-w64-mingw32)
endif
ifeq ($(TARGET),m68k-unknown-amigaos)
- SDK_ITEMS := $(addprefix $(BUILDSTEPS)/, libiconv.d libtre.d $(COMMON_SDK_ITEMS))
+ SDK_ITEMS := $(addprefix $(BUILDSTEPS)/, libiconv.d libtre.d libpbl.d $(COMMON_SDK_ITEMS))
EXTRAARGS_LIBCARES := --disable-shared --without-random
endif
diff --git a/sdk/recipes/patches/libiconv/ppc-amigaos/srclib.signal.in.h.p b/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.signal.in.h.p
similarity index 100%
copy from sdk/recipes/patches/libiconv/ppc-amigaos/srclib.signal.in.h.p
copy to sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.signal.in.h.p
diff --git a/sdk/recipes/patches/libiconv/ppc-amigaos/srclib.sigprocmask.c.p b/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.sigprocmask.c.p
similarity index 100%
copy from sdk/recipes/patches/libiconv/ppc-amigaos/srclib.sigprocmask.c.p
copy to sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.sigprocmask.c.p
diff --git a/sdk/recipes/patches/libiconv/ppc-amigaos/srclib.unistd.in.h.p b/sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.unistd.in.h.p
similarity index 100%
copy from sdk/recipes/patches/libiconv/ppc-amigaos/srclib.unistd.in.h.p
copy to sdk/recipes/patches/libiconv/m68k-unknown-amigaos/srclib.unistd.in.h.p
--
Cross-compilation toolchains and environments
8 years, 5 months
libnsutils: branch master updated. 4fc947676f34bb8157afaf0038c042ebcca16b1c
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/libnsutils.git/shortlog/4fc947676f34bb8157...
...commit http://git.netsurf-browser.org/libnsutils.git/commit/4fc947676f34bb8157af...
...tree http://git.netsurf-browser.org/libnsutils.git/tree/4fc947676f34bb8157afaf...
The branch, master has been updated
via 4fc947676f34bb8157afaf0038c042ebcca16b1c (commit)
from 228710c55bc4e8f69ad56ad981b25a0c4ce41a4c (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/libnsutils.git/commit/?id=4fc947676f34bb81...
commit 4fc947676f34bb8157afaf0038c042ebcca16b1c
Author: Vincent Sanders <vince(a)kyllikki.org>
Commit: Vincent Sanders <vince(a)kyllikki.org>
cope with HOST/BUILD change in buildsystem
diff --git a/Makefile b/Makefile
index b6a1448..807ba75 100644
--- a/Makefile
+++ b/Makefile
@@ -30,7 +30,7 @@ REQUIRED_LIBS := nsutils
# Strictly the requirement for rt is dependant on both the clib and if
# the build is using rt features like clock_gettime() but this check
# will suffice
-ifeq ($(BUILD),x86_64-linux-gnu)
+ifeq ($(HOST),x86_64-linux-gnu)
REQUIRED_LIBS := $(REQUIRED_LIBS) rt
endif
-----------------------------------------------------------------------
Summary of changes:
Makefile | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/Makefile b/Makefile
index b6a1448..807ba75 100644
--- a/Makefile
+++ b/Makefile
@@ -30,7 +30,7 @@ REQUIRED_LIBS := nsutils
# Strictly the requirement for rt is dependant on both the clib and if
# the build is using rt features like clock_gettime() but this check
# will suffice
-ifeq ($(BUILD),x86_64-linux-gnu)
+ifeq ($(HOST),x86_64-linux-gnu)
REQUIRED_LIBS := $(REQUIRED_LIBS) rt
endif
--
NetSurf generalised utility library
8 years, 5 months
libnsfb: branch master updated. release/0.1.2-3-g1ed0510
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/libnsfb.git/shortlog/1ed0510ce324535f355a0...
...commit http://git.netsurf-browser.org/libnsfb.git/commit/1ed0510ce324535f355a069...
...tree http://git.netsurf-browser.org/libnsfb.git/tree/1ed0510ce324535f355a06973...
The branch, master has been updated
via 1ed0510ce324535f355a069730cf4842097fc9c1 (commit)
from 751cf66a8861e14aa3b648cfd22a8e90cdb55079 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/libnsfb.git/commit/?id=1ed0510ce324535f355...
commit 1ed0510ce324535f355a069730cf4842097fc9c1
Author: Vincent Sanders <vince(a)kyllikki.org>
Commit: Vincent Sanders <vince(a)kyllikki.org>
Fix HOST/BUILD switchround for updated buildsystem
diff --git a/Makefile b/Makefile
index a33737f..6c827b6 100644
--- a/Makefile
+++ b/Makefile
@@ -33,7 +33,7 @@ $(eval $(call pkg_config_package_available,NSFB_WLD_AVAILABLE,wayland-client))
# surfaces not detectable via pkg-config
NSFB_ABLE_AVAILABLE := no
-ifeq ($(findstring linux,$(BUILD)),linux)
+ifeq ($(findstring linux,$(HOST)),linux)
NSFB_LINUX_AVAILABLE := yes
else
NSFB_LINUX_AVAILABLE := no
-----------------------------------------------------------------------
Summary of changes:
Makefile | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/Makefile b/Makefile
index a33737f..6c827b6 100644
--- a/Makefile
+++ b/Makefile
@@ -33,7 +33,7 @@ $(eval $(call pkg_config_package_available,NSFB_WLD_AVAILABLE,wayland-client))
# surfaces not detectable via pkg-config
NSFB_ABLE_AVAILABLE := no
-ifeq ($(findstring linux,$(BUILD)),linux)
+ifeq ($(findstring linux,$(HOST)),linux)
NSFB_LINUX_AVAILABLE := yes
else
NSFB_LINUX_AVAILABLE := no
--
NetSurf Framebuffer library
8 years, 5 months
toolchains: branch master updated. 110cc76ad1289310bf8c57183917b0ad58abf6d6
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/toolchains.git/shortlog/110cc76ad1289310bf...
...commit http://git.netsurf-browser.org/toolchains.git/commit/110cc76ad1289310bf8c...
...tree http://git.netsurf-browser.org/toolchains.git/tree/110cc76ad1289310bf8c57...
The branch, master has been updated
via 110cc76ad1289310bf8c57183917b0ad58abf6d6 (commit)
via 15d17ea200e595220c84cbca479436f95172ea1b (commit)
from 28b5c711c4c1d487c6640ea11a035184a02120a9 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/toolchains.git/commit/?id=110cc76ad1289310...
commit 110cc76ad1289310bf8c57183917b0ad58abf6d6
Author: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Commit: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Update openurl repo location
diff --git a/m68k-unknown-amigaos/Makefile b/m68k-unknown-amigaos/Makefile
index 494949c..3ee99f6 100644
--- a/m68k-unknown-amigaos/Makefile
+++ b/m68k-unknown-amigaos/Makefile
@@ -27,9 +27,9 @@ UPSTREAM_CLIB2_URI := anonymous@clib2.cvs.sourceforge.net:/cvsroot/clib2
UPSTREAM_NDK_TARBALL := ndk-3.9-includes.tar.bz2
UPSTREAM_NDK_URI := http://kas1e.mikendezign.com/zerohero_crosscompilers_backup/files/m68k-am...
-UPSTREAM_OPENURL_VERSION := 7.8
+UPSTREAM_OPENURL_VERSION := 7.15
UPSTREAM_OPENURL_TARBALL := openurl
-UPSTREAM_OPENURL_URI := https://openurllib.svn.sourceforge.net/svnroot/openurllib/releases/$(UPST...
+UPSTREAM_OPENURL_URI := http://svn.code.sf.net/p/openurllib/code/releases/$(UPSTREAM_OPENURL_VERS...
TOP := $(CURDIR)
RECIPES := $(TOP)/recipes
commitdiff http://git.netsurf-browser.org/toolchains.git/commit/?id=15d17ea200e59522...
commit 15d17ea200e595220c84cbca479436f95172ea1b
Author: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Commit: Chris Young <chris(a)unsatisfactorysoftware.co.uk>
Fix m68k binutils build
diff --git a/m68k-unknown-amigaos/recipes/patches/binutils/binutils.Makefile.in.p b/m68k-unknown-amigaos/recipes/patches/binutils/binutils.Makefile.in.p
new file mode 100644
index 0000000..0b6d02d
--- /dev/null
+++ b/m68k-unknown-amigaos/recipes/patches/binutils/binutils.Makefile.in.p
@@ -0,0 +1,11 @@
+--- binutils/Makefile.in 2014-12-19 12:37:51.912015855 +0000
++++ binutils/Makefile.in 2014-12-19 12:45:15.116014557 +0000
+@@ -481,7 +481,7 @@ LINK = $(LIBTOOL) --mode=link $(CCLD) $(
+ $(AM_LDFLAGS) $(LDFLAGS) -o $@
+ LEXCOMPILE = $(LEX) $(LFLAGS) $(AM_LFLAGS)
+ LTLEXCOMPILE = $(LIBTOOL) --mode=compile $(LEX) $(LFLAGS) $(AM_LFLAGS)
+-YLWRAP = $(top_srcdir)/ylwrap
++YLWRAP = $(top_srcdir)/../ylwrap
+ YACCCOMPILE = $(YACC) $(YFLAGS) $(AM_YFLAGS)
+ LTYACCCOMPILE = $(LIBTOOL) --mode=compile $(YACC) $(YFLAGS) $(AM_YFLAGS)
+ DIST_SOURCES = $(addr2line_SOURCES) $(ar_SOURCES) $(coffdump_SOURCES) \
diff --git a/m68k-unknown-amigaos/recipes/patches/binutils/ld.Makefile.in.p b/m68k-unknown-amigaos/recipes/patches/binutils/ld.Makefile.in.p
new file mode 100644
index 0000000..f1a1473
--- /dev/null
+++ b/m68k-unknown-amigaos/recipes/patches/binutils/ld.Makefile.in.p
@@ -0,0 +1,11 @@
+--- ld/Makefile.in 2014-12-19 12:37:47.280015870 +0000
++++ ld/Makefile.in 2014-12-19 12:44:38.192014671 +0000
+@@ -635,7 +635,7 @@ LEXCOMPILE = $(LEX) $(LFLAGS) $(AM_LFLAG
+ LTLEXCOMPILE = $(LIBTOOL) --mode=compile $(LEX) $(LFLAGS) $(AM_LFLAGS)
+ YACCCOMPILE = $(YACC) $(YFLAGS) $(AM_YFLAGS)
+ LTYACCCOMPILE = $(LIBTOOL) --mode=compile $(YACC) $(YFLAGS) $(AM_YFLAGS)
+-YLWRAP = $(top_srcdir)/ylwrap
++YLWRAP = $(top_srcdir)/../ylwrap
+ DIST_SOURCES = $(ld_new_SOURCES) $(EXTRA_ld_new_SOURCES)
+ TEXINFO_TEX = $(top_srcdir)/../texinfo/texinfo.tex
+ am__TEXINFO_TEX_DIR = $(top_srcdir)/../texinfo
diff --git a/m68k-unknown-amigaos/recipes/patches/binutils/ylwrap.p b/m68k-unknown-amigaos/recipes/patches/binutils/ylwrap.p
new file mode 100644
index 0000000..020dda1
--- /dev/null
+++ b/m68k-unknown-amigaos/recipes/patches/binutils/ylwrap.p
@@ -0,0 +1,291 @@
+--- ylwrap 2014-12-19 12:18:57.552019176 +0000
++++ ylwrap 2014-12-19 12:35:15.832016312 +0000
+@@ -1,6 +1,11 @@
+ #! /bin/sh
+ # ylwrap - wrapper for lex/yacc invocations.
+-# Copyright (C) 1996, 1997 Free Software Foundation, Inc.
++
++scriptversion=2005-05-14.22
++
++# Copyright (C) 1996, 1997, 1998, 1999, 2001, 2002, 2003, 2004, 2005
++# Free Software Foundation, Inc.
++#
+ # Written by Tom Tromey <tromey(a)cygnus.com>.
+ #
+ # This program is free software; you can redistribute it and/or modify
+@@ -15,58 +20,84 @@
+ #
+ # You should have received a copy of the GNU General Public License
+ # along with this program; if not, write to the Free Software
+-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+-
+-# Usage:
+-# ylwrap PROGRAM INPUT [OUTPUT DESIRED]... -- [ARGS]...
+-# * PROGRAM is program to run.
+-# * INPUT is the input file
+-# * OUTPUT is file PROG generates
+-# * DESIRED is file we actually want
+-# * ARGS are passed to PROG
+-# Any number of OUTPUT,DESIRED pairs may be used.
++# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
++# 02110-1301, USA.
+
+-# The program to run.
+-prog="$1"
+-shift
+-# Make any relative path in $prog absolute.
+-case "$prog" in
+- /* | [A-Za-z]:\\*) ;;
+- */*) prog="`pwd`/$prog" ;;
++# As a special exception to the GNU General Public License, if you
++# distribute this file as part of a program that contains a
++# configuration script generated by Autoconf, you may include it under
++# the same distribution terms that you use for the rest of that program.
++
++# This file is maintained in Automake, please report
++# bugs to <bug-automake(a)gnu.org> or send patches to
++# <automake-patches(a)gnu.org>.
++
++case "$1" in
++ '')
++ echo "$0: No files given. Try \`$0 --help' for more information." 1>&2
++ exit 1
++ ;;
++ --basedir)
++ basedir=$2
++ shift 2
++ ;;
++ -h|--h*)
++ cat <<\EOF
++Usage: ylwrap [--help|--version] INPUT [OUTPUT DESIRED]... -- PROGRAM [ARGS]...
++
++Wrapper for lex/yacc invocations, renaming files as desired.
++
++ INPUT is the input file
++ OUTPUT is one file PROG generates
++ DESIRED is the file we actually want instead of OUTPUT
++ PROGRAM is program to run
++ ARGS are passed to PROG
++
++Any number of OUTPUT,DESIRED pairs may be used.
++
++Report bugs to <bug-automake(a)gnu.org>.
++EOF
++ exit $?
++ ;;
++ -v|--v*)
++ echo "ylwrap $scriptversion"
++ exit $?
++ ;;
+ esac
+
++
+ # The input.
+ input="$1"
+ shift
+ case "$input" in
+- /* | [A-Za-z]:\\*)
++ [\\/]* | ?:[\\/]*)
+ # Absolute path; do nothing.
+ ;;
+- *)
+- # Relative path. Make it absolute. Why? Because otherwise any
+- # debugging info in the generated file will point to the wrong
+- # place. This is really gross.
++ *)
++ # Relative path. Make it absolute.
+ input="`pwd`/$input"
+ ;;
+ esac
+
+-# We don't want to use the absolute path if the input in the current
+-# directory like when making a tar ball.
+-input_base=`echo $input | sed -e 's|.*/||'`
+-if test -f $input_base && cmp $input_base $input >/dev/null 2>&1; then
+- input=$input_base
+-fi
+-
+ pairlist=
+ while test "$#" -ne 0; do
+- if test "$1" = "--"; then
+- shift
+- break
+- fi
+- pairlist="$pairlist $1"
+- shift
++ if test "$1" = "--"; then
++ shift
++ break
++ fi
++ pairlist="$pairlist $1"
++ shift
+ done
+
++# The program to run.
++prog="$1"
++shift
++# Make any relative path in $prog absolute.
++case "$prog" in
++ [\\/]* | ?:[\\/]*) ;;
++ *[\\/]*) prog="`pwd`/$prog" ;;
++esac
++
+ # FIXME: add hostname here for parallel makes that run commands on
+ # other machines. But that might take us over the 14-char limit.
+ dirname=ylwrap$$
+@@ -74,50 +105,119 @@ trap "cd `pwd`; rm -rf $dirname > /dev/n
+ mkdir $dirname || exit 1
+
+ cd $dirname
+-case "$input" in
+- /* | [A-Za-z]:\\*)
+- # Absolute path; do nothing.
+- ;;
+- *)
+- # Make a symbolic link, hard link or hardcopy.
+- ln -s ../"$input" . > /dev/null 2>&1 || ln ../"$input" . > /dev/null 2>&1 || cp ../"$input" .
+- ;;
++
++case $# in
++ 0) $prog "$input" ;;
++ *) $prog "$@" "$input" ;;
+ esac
+-$prog ${1+"$@"} "$input"
+-status=$?
++ret=$?
+
+-if test $status -eq 0; then
+- set X $pairlist
+- shift
+- first=yes
+- while test "$#" -ne 0; do
+- if test -f "$1"; then
+- # If $2 is an absolute path name, then just use that,
+- # otherwise prepend `../'.
+- case "$2" in
+- /* | [A-Za-z]:\\*) target="$2";;
+- *) target="../$2";;
+- esac
+- mv "$1" "$target" || status=$?
++if test $ret -eq 0; then
++ set X $pairlist
++ shift
++ first=yes
++ # Since DOS filename conventions don't allow two dots,
++ # the DOS version of Bison writes out y_tab.c instead of y.tab.c
++ # and y_tab.h instead of y.tab.h. Test to see if this is the case.
++ y_tab_nodot="no"
++ if test -f y_tab.c || test -f y_tab.h; then
++ y_tab_nodot="yes"
++ fi
++
++ # The directory holding the input.
++ input_dir=`echo "$input" | sed -e 's,\([\\/]\)[^\\/]*$,\1,'`
++ # Quote $INPUT_DIR so we can use it in a regexp.
++ # FIXME: really we should care about more than `.' and `\'.
++ input_rx=`echo "$input_dir" | sed 's,\\\\,\\\\\\\\,g;s,\\.,\\\\.,g'`
++
++ while test "$#" -ne 0; do
++ from="$1"
++ # Handle y_tab.c and y_tab.h output by DOS
++ if test $y_tab_nodot = "yes"; then
++ if test $from = "y.tab.c"; then
++ from="y_tab.c"
+ else
+- # A missing file is only an error for the first file. This
+- # is a blatant hack to let us support using "yacc -d". If -d
+- # is not specified, we don't want an error when the header
+- # file is "missing".
+- if test $first = yes; then
+- status=1
+- fi
++ if test $from = "y.tab.h"; then
++ from="y_tab.h"
++ fi
+ fi
+- shift
+- shift
+- first=no
+- done
++ fi
++ if test -f "$from"; then
++ # If $2 is an absolute path name, then just use that,
++ # otherwise prepend `../'.
++ case "$2" in
++ [\\/]* | ?:[\\/]*) target="$2";;
++ *) target="../$2";;
++ esac
++
++ # We do not want to overwrite a header file if it hasn't
++ # changed. This avoid useless recompilations. However the
++ # parser itself (the first file) should always be updated,
++ # because it is the destination of the .y.c rule in the
++ # Makefile. Divert the output of all other files to a temporary
++ # file so we can compare them to existing versions.
++ if test $first = no; then
++ realtarget="$target"
++ target="tmp-`echo $target | sed s/.*[\\/]//g`"
++ fi
++ # Edit out `#line' or `#' directives.
++ #
++ # We don't want the resulting debug information to point at
++ # an absolute srcdir; it is better for it to just mention the
++ # .y file with no path.
++ #
++ # We want to use the real output file name, not yy.lex.c for
++ # instance.
++ #
++ # We want the include guards to be adjusted too.
++ FROM=`echo "$from" | sed \
++ -e 'y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/'\
++ -e 's/[^ABCDEFGHIJKLMNOPQRSTUVWXYZ]/_/g'`
++ TARGET=`echo "$2" | sed \
++ -e 'y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/'\
++ -e 's/[^ABCDEFGHIJKLMNOPQRSTUVWXYZ]/_/g'`
++
++ sed -e "/^#/!b" -e "s,$input_rx,," -e "s,$from,$2," \
++ -e "s,$FROM,$TARGET," "$from" >"$target" || ret=$?
++
++ # Check whether header files must be updated.
++ if test $first = no; then
++ if test -f "$realtarget" && cmp -s "$realtarget" "$target"; then
++ echo "$2" is unchanged
++ rm -f "$target"
++ else
++ echo updating "$2"
++ mv -f "$target" "$realtarget"
++ fi
++ fi
++ else
++ # A missing file is only an error for the first file. This
++ # is a blatant hack to let us support using "yacc -d". If -d
++ # is not specified, we don't want an error when the header
++ # file is "missing".
++ if test $first = yes; then
++ ret=1
++ fi
++ fi
++ shift
++ shift
++ first=no
++ done
+ else
+- status=$?
++ ret=$?
+ fi
+
+ # Remove the directory.
+ cd ..
+ rm -rf $dirname
+
+-exit $status
++exit $ret
++
++# Local Variables:
++# mode: shell-script
++# sh-indentation: 2
++# eval: (add-hook 'write-file-hooks 'time-stamp)
++# time-stamp-start: "scriptversion="
++# time-stamp-format: "%:y-%02m-%02d.%02H"
++# time-stamp-end: "$"
++# End:
-----------------------------------------------------------------------
Summary of changes:
m68k-unknown-amigaos/Makefile | 4 +-
.../patches/binutils/binutils.Makefile.in.p | 11 +
.../recipes/patches/binutils/ld.Makefile.in.p | 11 +
.../recipes/patches/binutils/ylwrap.p | 291 ++++++++++++++++++++
4 files changed, 315 insertions(+), 2 deletions(-)
create mode 100644 m68k-unknown-amigaos/recipes/patches/binutils/binutils.Makefile.in.p
create mode 100644 m68k-unknown-amigaos/recipes/patches/binutils/ld.Makefile.in.p
create mode 100644 m68k-unknown-amigaos/recipes/patches/binutils/ylwrap.p
diff --git a/m68k-unknown-amigaos/Makefile b/m68k-unknown-amigaos/Makefile
index 494949c..3ee99f6 100644
--- a/m68k-unknown-amigaos/Makefile
+++ b/m68k-unknown-amigaos/Makefile
@@ -27,9 +27,9 @@ UPSTREAM_CLIB2_URI := anonymous@clib2.cvs.sourceforge.net:/cvsroot/clib2
UPSTREAM_NDK_TARBALL := ndk-3.9-includes.tar.bz2
UPSTREAM_NDK_URI := http://kas1e.mikendezign.com/zerohero_crosscompilers_backup/files/m68k-am...
-UPSTREAM_OPENURL_VERSION := 7.8
+UPSTREAM_OPENURL_VERSION := 7.15
UPSTREAM_OPENURL_TARBALL := openurl
-UPSTREAM_OPENURL_URI := https://openurllib.svn.sourceforge.net/svnroot/openurllib/releases/$(UPST...
+UPSTREAM_OPENURL_URI := http://svn.code.sf.net/p/openurllib/code/releases/$(UPSTREAM_OPENURL_VERS...
TOP := $(CURDIR)
RECIPES := $(TOP)/recipes
diff --git a/m68k-unknown-amigaos/recipes/patches/binutils/binutils.Makefile.in.p b/m68k-unknown-amigaos/recipes/patches/binutils/binutils.Makefile.in.p
new file mode 100644
index 0000000..0b6d02d
--- /dev/null
+++ b/m68k-unknown-amigaos/recipes/patches/binutils/binutils.Makefile.in.p
@@ -0,0 +1,11 @@
+--- binutils/Makefile.in 2014-12-19 12:37:51.912015855 +0000
++++ binutils/Makefile.in 2014-12-19 12:45:15.116014557 +0000
+@@ -481,7 +481,7 @@ LINK = $(LIBTOOL) --mode=link $(CCLD) $(
+ $(AM_LDFLAGS) $(LDFLAGS) -o $@
+ LEXCOMPILE = $(LEX) $(LFLAGS) $(AM_LFLAGS)
+ LTLEXCOMPILE = $(LIBTOOL) --mode=compile $(LEX) $(LFLAGS) $(AM_LFLAGS)
+-YLWRAP = $(top_srcdir)/ylwrap
++YLWRAP = $(top_srcdir)/../ylwrap
+ YACCCOMPILE = $(YACC) $(YFLAGS) $(AM_YFLAGS)
+ LTYACCCOMPILE = $(LIBTOOL) --mode=compile $(YACC) $(YFLAGS) $(AM_YFLAGS)
+ DIST_SOURCES = $(addr2line_SOURCES) $(ar_SOURCES) $(coffdump_SOURCES) \
diff --git a/m68k-unknown-amigaos/recipes/patches/binutils/ld.Makefile.in.p b/m68k-unknown-amigaos/recipes/patches/binutils/ld.Makefile.in.p
new file mode 100644
index 0000000..f1a1473
--- /dev/null
+++ b/m68k-unknown-amigaos/recipes/patches/binutils/ld.Makefile.in.p
@@ -0,0 +1,11 @@
+--- ld/Makefile.in 2014-12-19 12:37:47.280015870 +0000
++++ ld/Makefile.in 2014-12-19 12:44:38.192014671 +0000
+@@ -635,7 +635,7 @@ LEXCOMPILE = $(LEX) $(LFLAGS) $(AM_LFLAG
+ LTLEXCOMPILE = $(LIBTOOL) --mode=compile $(LEX) $(LFLAGS) $(AM_LFLAGS)
+ YACCCOMPILE = $(YACC) $(YFLAGS) $(AM_YFLAGS)
+ LTYACCCOMPILE = $(LIBTOOL) --mode=compile $(YACC) $(YFLAGS) $(AM_YFLAGS)
+-YLWRAP = $(top_srcdir)/ylwrap
++YLWRAP = $(top_srcdir)/../ylwrap
+ DIST_SOURCES = $(ld_new_SOURCES) $(EXTRA_ld_new_SOURCES)
+ TEXINFO_TEX = $(top_srcdir)/../texinfo/texinfo.tex
+ am__TEXINFO_TEX_DIR = $(top_srcdir)/../texinfo
diff --git a/m68k-unknown-amigaos/recipes/patches/binutils/ylwrap.p b/m68k-unknown-amigaos/recipes/patches/binutils/ylwrap.p
new file mode 100644
index 0000000..020dda1
--- /dev/null
+++ b/m68k-unknown-amigaos/recipes/patches/binutils/ylwrap.p
@@ -0,0 +1,291 @@
+--- ylwrap 2014-12-19 12:18:57.552019176 +0000
++++ ylwrap 2014-12-19 12:35:15.832016312 +0000
+@@ -1,6 +1,11 @@
+ #! /bin/sh
+ # ylwrap - wrapper for lex/yacc invocations.
+-# Copyright (C) 1996, 1997 Free Software Foundation, Inc.
++
++scriptversion=2005-05-14.22
++
++# Copyright (C) 1996, 1997, 1998, 1999, 2001, 2002, 2003, 2004, 2005
++# Free Software Foundation, Inc.
++#
+ # Written by Tom Tromey <tromey(a)cygnus.com>.
+ #
+ # This program is free software; you can redistribute it and/or modify
+@@ -15,58 +20,84 @@
+ #
+ # You should have received a copy of the GNU General Public License
+ # along with this program; if not, write to the Free Software
+-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+-
+-# Usage:
+-# ylwrap PROGRAM INPUT [OUTPUT DESIRED]... -- [ARGS]...
+-# * PROGRAM is program to run.
+-# * INPUT is the input file
+-# * OUTPUT is file PROG generates
+-# * DESIRED is file we actually want
+-# * ARGS are passed to PROG
+-# Any number of OUTPUT,DESIRED pairs may be used.
++# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
++# 02110-1301, USA.
+
+-# The program to run.
+-prog="$1"
+-shift
+-# Make any relative path in $prog absolute.
+-case "$prog" in
+- /* | [A-Za-z]:\\*) ;;
+- */*) prog="`pwd`/$prog" ;;
++# As a special exception to the GNU General Public License, if you
++# distribute this file as part of a program that contains a
++# configuration script generated by Autoconf, you may include it under
++# the same distribution terms that you use for the rest of that program.
++
++# This file is maintained in Automake, please report
++# bugs to <bug-automake(a)gnu.org> or send patches to
++# <automake-patches(a)gnu.org>.
++
++case "$1" in
++ '')
++ echo "$0: No files given. Try \`$0 --help' for more information." 1>&2
++ exit 1
++ ;;
++ --basedir)
++ basedir=$2
++ shift 2
++ ;;
++ -h|--h*)
++ cat <<\EOF
++Usage: ylwrap [--help|--version] INPUT [OUTPUT DESIRED]... -- PROGRAM [ARGS]...
++
++Wrapper for lex/yacc invocations, renaming files as desired.
++
++ INPUT is the input file
++ OUTPUT is one file PROG generates
++ DESIRED is the file we actually want instead of OUTPUT
++ PROGRAM is program to run
++ ARGS are passed to PROG
++
++Any number of OUTPUT,DESIRED pairs may be used.
++
++Report bugs to <bug-automake(a)gnu.org>.
++EOF
++ exit $?
++ ;;
++ -v|--v*)
++ echo "ylwrap $scriptversion"
++ exit $?
++ ;;
+ esac
+
++
+ # The input.
+ input="$1"
+ shift
+ case "$input" in
+- /* | [A-Za-z]:\\*)
++ [\\/]* | ?:[\\/]*)
+ # Absolute path; do nothing.
+ ;;
+- *)
+- # Relative path. Make it absolute. Why? Because otherwise any
+- # debugging info in the generated file will point to the wrong
+- # place. This is really gross.
++ *)
++ # Relative path. Make it absolute.
+ input="`pwd`/$input"
+ ;;
+ esac
+
+-# We don't want to use the absolute path if the input in the current
+-# directory like when making a tar ball.
+-input_base=`echo $input | sed -e 's|.*/||'`
+-if test -f $input_base && cmp $input_base $input >/dev/null 2>&1; then
+- input=$input_base
+-fi
+-
+ pairlist=
+ while test "$#" -ne 0; do
+- if test "$1" = "--"; then
+- shift
+- break
+- fi
+- pairlist="$pairlist $1"
+- shift
++ if test "$1" = "--"; then
++ shift
++ break
++ fi
++ pairlist="$pairlist $1"
++ shift
+ done
+
++# The program to run.
++prog="$1"
++shift
++# Make any relative path in $prog absolute.
++case "$prog" in
++ [\\/]* | ?:[\\/]*) ;;
++ *[\\/]*) prog="`pwd`/$prog" ;;
++esac
++
+ # FIXME: add hostname here for parallel makes that run commands on
+ # other machines. But that might take us over the 14-char limit.
+ dirname=ylwrap$$
+@@ -74,50 +105,119 @@ trap "cd `pwd`; rm -rf $dirname > /dev/n
+ mkdir $dirname || exit 1
+
+ cd $dirname
+-case "$input" in
+- /* | [A-Za-z]:\\*)
+- # Absolute path; do nothing.
+- ;;
+- *)
+- # Make a symbolic link, hard link or hardcopy.
+- ln -s ../"$input" . > /dev/null 2>&1 || ln ../"$input" . > /dev/null 2>&1 || cp ../"$input" .
+- ;;
++
++case $# in
++ 0) $prog "$input" ;;
++ *) $prog "$@" "$input" ;;
+ esac
+-$prog ${1+"$@"} "$input"
+-status=$?
++ret=$?
+
+-if test $status -eq 0; then
+- set X $pairlist
+- shift
+- first=yes
+- while test "$#" -ne 0; do
+- if test -f "$1"; then
+- # If $2 is an absolute path name, then just use that,
+- # otherwise prepend `../'.
+- case "$2" in
+- /* | [A-Za-z]:\\*) target="$2";;
+- *) target="../$2";;
+- esac
+- mv "$1" "$target" || status=$?
++if test $ret -eq 0; then
++ set X $pairlist
++ shift
++ first=yes
++ # Since DOS filename conventions don't allow two dots,
++ # the DOS version of Bison writes out y_tab.c instead of y.tab.c
++ # and y_tab.h instead of y.tab.h. Test to see if this is the case.
++ y_tab_nodot="no"
++ if test -f y_tab.c || test -f y_tab.h; then
++ y_tab_nodot="yes"
++ fi
++
++ # The directory holding the input.
++ input_dir=`echo "$input" | sed -e 's,\([\\/]\)[^\\/]*$,\1,'`
++ # Quote $INPUT_DIR so we can use it in a regexp.
++ # FIXME: really we should care about more than `.' and `\'.
++ input_rx=`echo "$input_dir" | sed 's,\\\\,\\\\\\\\,g;s,\\.,\\\\.,g'`
++
++ while test "$#" -ne 0; do
++ from="$1"
++ # Handle y_tab.c and y_tab.h output by DOS
++ if test $y_tab_nodot = "yes"; then
++ if test $from = "y.tab.c"; then
++ from="y_tab.c"
+ else
+- # A missing file is only an error for the first file. This
+- # is a blatant hack to let us support using "yacc -d". If -d
+- # is not specified, we don't want an error when the header
+- # file is "missing".
+- if test $first = yes; then
+- status=1
+- fi
++ if test $from = "y.tab.h"; then
++ from="y_tab.h"
++ fi
+ fi
+- shift
+- shift
+- first=no
+- done
++ fi
++ if test -f "$from"; then
++ # If $2 is an absolute path name, then just use that,
++ # otherwise prepend `../'.
++ case "$2" in
++ [\\/]* | ?:[\\/]*) target="$2";;
++ *) target="../$2";;
++ esac
++
++ # We do not want to overwrite a header file if it hasn't
++ # changed. This avoid useless recompilations. However the
++ # parser itself (the first file) should always be updated,
++ # because it is the destination of the .y.c rule in the
++ # Makefile. Divert the output of all other files to a temporary
++ # file so we can compare them to existing versions.
++ if test $first = no; then
++ realtarget="$target"
++ target="tmp-`echo $target | sed s/.*[\\/]//g`"
++ fi
++ # Edit out `#line' or `#' directives.
++ #
++ # We don't want the resulting debug information to point at
++ # an absolute srcdir; it is better for it to just mention the
++ # .y file with no path.
++ #
++ # We want to use the real output file name, not yy.lex.c for
++ # instance.
++ #
++ # We want the include guards to be adjusted too.
++ FROM=`echo "$from" | sed \
++ -e 'y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/'\
++ -e 's/[^ABCDEFGHIJKLMNOPQRSTUVWXYZ]/_/g'`
++ TARGET=`echo "$2" | sed \
++ -e 'y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/'\
++ -e 's/[^ABCDEFGHIJKLMNOPQRSTUVWXYZ]/_/g'`
++
++ sed -e "/^#/!b" -e "s,$input_rx,," -e "s,$from,$2," \
++ -e "s,$FROM,$TARGET," "$from" >"$target" || ret=$?
++
++ # Check whether header files must be updated.
++ if test $first = no; then
++ if test -f "$realtarget" && cmp -s "$realtarget" "$target"; then
++ echo "$2" is unchanged
++ rm -f "$target"
++ else
++ echo updating "$2"
++ mv -f "$target" "$realtarget"
++ fi
++ fi
++ else
++ # A missing file is only an error for the first file. This
++ # is a blatant hack to let us support using "yacc -d". If -d
++ # is not specified, we don't want an error when the header
++ # file is "missing".
++ if test $first = yes; then
++ ret=1
++ fi
++ fi
++ shift
++ shift
++ first=no
++ done
+ else
+- status=$?
++ ret=$?
+ fi
+
+ # Remove the directory.
+ cd ..
+ rm -rf $dirname
+
+-exit $status
++exit $ret
++
++# Local Variables:
++# mode: shell-script
++# sh-indentation: 2
++# eval: (add-hook 'write-file-hooks 'time-stamp)
++# time-stamp-start: "scriptversion="
++# time-stamp-format: "%:y-%02m-%02d.%02H"
++# time-stamp-end: "$"
++# End:
--
Cross-compilation toolchains and environments
8 years, 5 months
netsurf: branch master updated. release/3.2-533-g876b6cb
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/netsurf.git/shortlog/876b6cbeb0eaf718f17bd...
...commit http://git.netsurf-browser.org/netsurf.git/commit/876b6cbeb0eaf718f17bdba...
...tree http://git.netsurf-browser.org/netsurf.git/tree/876b6cbeb0eaf718f17bdbadf...
The branch, master has been updated
via 876b6cbeb0eaf718f17bdbadf37182cb72730d81 (commit)
from ef43be99895f9da0fed1806432fd23dc9f12d36e (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/netsurf.git/commit/?id=876b6cbeb0eaf718f17...
commit 876b6cbeb0eaf718f17bdbadf37182cb72730d81
Author: Vincent Sanders <vince(a)kyllikki.org>
Commit: Vincent Sanders <vince(a)kyllikki.org>
fix BUILD/HOST usage to work with fixed buildsystem
diff --git a/Docs/env.sh b/Docs/env.sh
index ad85d81..3456c4d 100644
--- a/Docs/env.sh
+++ b/Docs/env.sh
@@ -3,7 +3,7 @@
# NetSurf Library, tool and browser support script
#
# Usage: source env.sh
-# TARGET_ABI sets the target for library builds
+# TARGET_ABI / HOST sets the target for library builds
# TARGET_WORKSPACE is the workspace directory to keep the sandboxes
#
# This script allows NetSurf and its libraries to be built without
@@ -13,8 +13,19 @@
# Released under the MIT Licence
# parameters
-if [ "x${TARGET_ABI}" = "x" ]; then
- TARGET_ABI=$(cc -dumpmachine)
+
+# The system doing the building
+if [ "x${BUILD}" = "x" ]; then
+ BUILD=$(cc -dumpmachine)
+fi
+
+# Get the host build if unset
+if [ "x${HOST}" = "x" ]; then
+ if [ "x${TARGET_ABI}" = "x" ]; then
+ HOST=${BUILD}
+ else
+ HOST=${TARGET_ABI}
+ fi
fi
if [ "x${TARGET_WORKSPACE}" = "x" ]; then
@@ -33,16 +44,17 @@ if [ "x${NETSURF_GTK_MAJOR}" = "x" ]; then
NETSURF_GTK_MAJOR=3
fi
-# The host system doing the building
-HOST_ABI=$(cc -dumpmachine)
-# setup environment
-echo "HOST_ABI=${HOST_ABI}"
-echo "TARGET_ABI=${TARGET_ABI}"
+###############################################################################
+# Setup environment
+###############################################################################
+
+echo "BUILD=${BUILD}"
+echo "HOST=${HOST}"
echo "TARGET_WORKSPACE=${TARGET_WORKSPACE}"
echo "USE_CPUS=${USE_CPUS}"
-export PREFIX=${TARGET_WORKSPACE}/inst-${TARGET_ABI}
+export PREFIX=${TARGET_WORKSPACE}/inst-${HOST}
export PKG_CONFIG_PATH=${PREFIX}/lib/pkgconfig:${PKG_CONFIG_PATH}::
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${PREFIX}/lib
export PATH=${PATH}:${PREFIX}/bin
@@ -58,7 +70,7 @@ NS_INTERNAL_LIBS="buildsystem libwapcaplet libparserutils libhubbub libdom libcs
NS_BROWSER="netsurf"
# add target specific libraries
-case "${TARGET_ABI}" in
+case "${HOST}" in
i586-pc-haiku)
# tools required to build the browser for haiku (beos)
NS_TOOLS=""
@@ -83,6 +95,12 @@ case "${TARGET_ABI}" in
# libraries required for the atari frontend
NS_FRONTEND_LIBS=""
;;
+ ppc-amigaos)
+ # default tools required to build the browser
+ NS_TOOLS="nsgenbind"
+ # default additional internal libraries
+ NS_FRONTEND_LIBS="libsvgtiny"
+ ;;
*)
# default tools required to build the browser
NS_TOOLS="nsgenbind"
@@ -211,11 +229,17 @@ ns-make-libs()
for REPO in $(echo ${NS_TOOLS}); do
echo " MAKE: make -C ${REPO} $USE_CPUS $*"
make -C ${TARGET_WORKSPACE}/${REPO} $USE_CPUS $*
+ if [ $? -ne 0]; then
+ exit $?
+ fi
done
for REPO in $(echo ${NS_INTERNAL_LIBS} ${NS_FRONTEND_LIBS}); do
echo " MAKE: make -C ${REPO} $USE_CPUS $*"
- make -C ${TARGET_WORKSPACE}/${REPO} BUILD=${TARGET_ABI} $USE_CPUS $*
+ make -C ${TARGET_WORKSPACE}/${REPO} HOST=${HOST} $USE_CPUS $*
+ if [ $? -ne 0]; then
+ exit $?
+ fi
done
}
@@ -223,7 +247,7 @@ ns-make-libs()
ns-make-libnsfb()
{
echo " MAKE: make -C libnsfb $USE_CPUS $*"
- make -C ${TARGET_WORKSPACE}/libnsfb BUILD=${TARGET_ABI} $USE_CPUS $*
+ make -C ${TARGET_WORKSPACE}/libnsfb HOST=${HOST} $USE_CPUS $*
}
# pulls all repos and makes and installs the libraries and tools
diff --git a/Docs/env.sh b/Docs/env.sh
index ad85d81..3456c4d 100644
--- a/Docs/env.sh
+++ b/Docs/env.sh
@@ -3,7 +3,7 @@
# NetSurf Library, tool and browser support script
#
# Usage: source env.sh
-# TARGET_ABI sets the target for library builds
+# TARGET_ABI / HOST sets the target for library builds
# TARGET_WORKSPACE is the workspace directory to keep the sandboxes
#
# This script allows NetSurf and its libraries to be built without
@@ -13,8 +13,19 @@
# Released under the MIT Licence
# parameters
-if [ "x${TARGET_ABI}" = "x" ]; then
- TARGET_ABI=$(cc -dumpmachine)
+
+# The system doing the building
+if [ "x${BUILD}" = "x" ]; then
+ BUILD=$(cc -dumpmachine)
+fi
+
+# Get the host build if unset
+if [ "x${HOST}" = "x" ]; then
+ if [ "x${TARGET_ABI}" = "x" ]; then
+ HOST=${BUILD}
+ else
+ HOST=${TARGET_ABI}
+ fi
fi
if [ "x${TARGET_WORKSPACE}" = "x" ]; then
@@ -33,16 +44,17 @@ if [ "x${NETSURF_GTK_MAJOR}" = "x" ]; then
NETSURF_GTK_MAJOR=3
fi
-# The host system doing the building
-HOST_ABI=$(cc -dumpmachine)
-# setup environment
-echo "HOST_ABI=${HOST_ABI}"
-echo "TARGET_ABI=${TARGET_ABI}"
+###############################################################################
+# Setup environment
+###############################################################################
+
+echo "BUILD=${BUILD}"
+echo "HOST=${HOST}"
echo "TARGET_WORKSPACE=${TARGET_WORKSPACE}"
echo "USE_CPUS=${USE_CPUS}"
-export PREFIX=${TARGET_WORKSPACE}/inst-${TARGET_ABI}
+export PREFIX=${TARGET_WORKSPACE}/inst-${HOST}
export PKG_CONFIG_PATH=${PREFIX}/lib/pkgconfig:${PKG_CONFIG_PATH}::
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${PREFIX}/lib
export PATH=${PATH}:${PREFIX}/bin
@@ -58,7 +70,7 @@ NS_INTERNAL_LIBS="buildsystem libwapcaplet libparserutils libhubbub libdom libcs
NS_BROWSER="netsurf"
# add target specific libraries
-case "${TARGET_ABI}" in
+case "${HOST}" in
i586-pc-haiku)
# tools required to build the browser for haiku (beos)
NS_TOOLS=""
@@ -83,6 +95,12 @@ case "${TARGET_ABI}" in
# libraries required for the atari frontend
NS_FRONTEND_LIBS=""
;;
+ ppc-amigaos)
+ # default tools required to build the browser
+ NS_TOOLS="nsgenbind"
+ # default additional internal libraries
+ NS_FRONTEND_LIBS="libsvgtiny"
+ ;;
*)
# default tools required to build the browser
NS_TOOLS="nsgenbind"
@@ -211,11 +229,17 @@ ns-make-libs()
for REPO in $(echo ${NS_TOOLS}); do
echo " MAKE: make -C ${REPO} $USE_CPUS $*"
make -C ${TARGET_WORKSPACE}/${REPO} $USE_CPUS $*
+ if [ $? -ne 0]; then
+ exit $?
+ fi
done
for REPO in $(echo ${NS_INTERNAL_LIBS} ${NS_FRONTEND_LIBS}); do
echo " MAKE: make -C ${REPO} $USE_CPUS $*"
- make -C ${TARGET_WORKSPACE}/${REPO} BUILD=${TARGET_ABI} $USE_CPUS $*
+ make -C ${TARGET_WORKSPACE}/${REPO} HOST=${HOST} $USE_CPUS $*
+ if [ $? -ne 0]; then
+ exit $?
+ fi
done
}
@@ -223,7 +247,7 @@ ns-make-libs()
ns-make-libnsfb()
{
echo " MAKE: make -C libnsfb $USE_CPUS $*"
- make -C ${TARGET_WORKSPACE}/libnsfb BUILD=${TARGET_ABI} $USE_CPUS $*
+ make -C ${TARGET_WORKSPACE}/libnsfb HOST=${HOST} $USE_CPUS $*
}
# pulls all repos and makes and installs the libraries and tools
--
NetSurf Browser
8 years, 5 months
libdom: branch master updated. release/0.1.1-6-g99d4ae0
by NetSurf Browser Project
Gitweb links:
...log http://git.netsurf-browser.org/libdom.git/shortlog/99d4ae0054f8e4d681f5a7...
...commit http://git.netsurf-browser.org/libdom.git/commit/99d4ae0054f8e4d681f5a7dd...
...tree http://git.netsurf-browser.org/libdom.git/tree/99d4ae0054f8e4d681f5a7dd0f...
The branch, master has been updated
via 99d4ae0054f8e4d681f5a7dd0f3bf2f0ce7df27a (commit)
from ada8b3c6abeaa2d08c3ed1c349bdade4843a028c (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commitdiff http://git.netsurf-browser.org/libdom.git/commit/?id=99d4ae0054f8e4d681f5...
commit 99d4ae0054f8e4d681f5a7dd0f3bf2f0ce7df27a
Author: Vincent Sanders <vince(a)kyllikki.org>
Commit: Vincent Sanders <vince(a)kyllikki.org>
Update to use correct BUILD/HOST variables due to buildsystem changes
diff --git a/Makefile b/Makefile
index c9c1bd7..14fea99 100644
--- a/Makefile
+++ b/Makefile
@@ -16,11 +16,11 @@ WARNFLAGS := -Wall -W -Wundef -Wpointer-arith -Wcast-align \
-Wwrite-strings -Wstrict-prototypes -Wmissing-prototypes \
-Wmissing-declarations -Wnested-externs
# BeOS/Haiku standard library headers generate warnings
-ifneq ($(BUILD),i586-pc-haiku)
+ifneq ($(HOST),i586-pc-haiku)
WARNFLAGS := $(WARNFLAGS) -Werror
endif
# AmigaOS needs this to avoid warnings
-ifeq ($(findstring amigaos,$(BUILD)),amigaos)
+ifeq ($(findstring amigaos,$(HOST)),amigaos)
CFLAGS := -U__STRICT_ANSI__ $(CFLAGS)
endif
CFLAGS := -D_BSD_SOURCE -I$(CURDIR)/include/ \
-----------------------------------------------------------------------
Summary of changes:
Makefile | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/Makefile b/Makefile
index c9c1bd7..14fea99 100644
--- a/Makefile
+++ b/Makefile
@@ -16,11 +16,11 @@ WARNFLAGS := -Wall -W -Wundef -Wpointer-arith -Wcast-align \
-Wwrite-strings -Wstrict-prototypes -Wmissing-prototypes \
-Wmissing-declarations -Wnested-externs
# BeOS/Haiku standard library headers generate warnings
-ifneq ($(BUILD),i586-pc-haiku)
+ifneq ($(HOST),i586-pc-haiku)
WARNFLAGS := $(WARNFLAGS) -Werror
endif
# AmigaOS needs this to avoid warnings
-ifeq ($(findstring amigaos,$(BUILD)),amigaos)
+ifeq ($(findstring amigaos,$(HOST)),amigaos)
CFLAGS := -U__STRICT_ANSI__ $(CFLAGS)
endif
CFLAGS := -D_BSD_SOURCE -I$(CURDIR)/include/ \
diff --git a/utils/jenkins-build.sh b/utils/jenkins-build.sh
index b4704c9..e7de93d 100755
--- a/utils/jenkins-build.sh
+++ b/utils/jenkins-build.sh
@@ -28,7 +28,7 @@
#
# TARGET is set to the frontend target to build
# BUILD is set to the identifier of the toolchain doing the building
# CC is the compiler (gcc or clang)
# BUILD_JS is the javascript type (json or jsoff)
# BUILD_NUMBER is the CI build number
@@ -56,13 +56,13 @@ MAKE=make
# specific parameters too
case ${TARGET} in
"riscos")
- case ${BUILD} in
+ case ${HOST} in
"arm-unknown-riscos")
ARTIFACT_TARGET=riscos
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -73,13 +73,13 @@ case ${TARGET} in
;;
"haiku")
- case ${BUILD} in
+ case ${HOST} in
"i586-pc-haiku")
ARTIFACT_TARGET=Haiku
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -91,13 +91,13 @@ case ${TARGET} in
"windows")
- case ${BUILD} in
+ case ${HOST} in
"i686-w64-mingw32")
ARTIFACT_TARGET=windows
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -109,11 +109,11 @@ case ${TARGET} in
"cocoa")
- case ${BUILD} in
+ case ${HOST} in
"i686-apple-darwin10")
ARTIFACT_TARGET=Darwin
- IDENTIFIER="${BUILD}-${IDENTIFIER}"
- OLD_IDENTIFIER="${BUILD}-${OLD_IDENTIFIER}"
+ IDENTIFIER="${HOST}-${IDENTIFIER}"
+ OLD_IDENTIFIER="${HOST}-${OLD_IDENTIFIER}"
;;
"powerpc-apple-darwin9")
@@ -123,7 +123,7 @@ case ${TARGET} in
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -135,13 +135,13 @@ case ${TARGET} in
"amiga")
- case ${BUILD} in
+ case ${HOST} in
"ppc-amigaos")
ARTIFACT_TARGET=amiga
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -153,7 +153,7 @@ case ${TARGET} in
"atari")
- case ${BUILD} in
+ case ${HOST} in
"m68k-atari-mint")
ARTIFACT_TARGET=m68k-atari-mint
PKG_SRC=ns020
@@ -170,7 +170,7 @@ case ${TARGET} in
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -182,7 +182,7 @@ case ${TARGET} in
"gtk")
- case ${BUILD} in
+ case ${HOST} in
"x86_64-linux-gnu")
ARTIFACT_TARGET=Linux
;;
@@ -193,7 +193,7 @@ case ${TARGET} in
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD}\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST}\""
exit 1
;;
@@ -205,7 +205,7 @@ case ${TARGET} in
"framebuffer")
- case ${BUILD} in
+ case ${HOST} in
"x86_64-linux-gnu")
ARTIFACT_TARGET=Linux
;;
@@ -220,37 +220,37 @@ case ${TARGET} in
"arm-unknown-riscos")
ARTIFACT_TARGET=riscos
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"m68k-atari-mint")
ARTIFACT_TARGET=m68k-atari-mint
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"m5475-atari-mint")
ATARIARCH=v4e
ARTIFACT_TARGET=m5475-atari-mint
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"i686-w64-mingw32")
ARTIFACT_TARGET=windows
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"ppc-amigaos")
ARTIFACT_TARGET=amiga
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -263,7 +263,7 @@ case ${TARGET} in
"monkey")
# monkey target can be built on most of the supported architectures
- case ${BUILD} in
+ case ${HOST} in
"x86_64-linux-gnu")
ARTIFACT_TARGET=Linux
;;
@@ -278,44 +278,44 @@ case ${TARGET} in
"arm-unknown-riscos")
ARTIFACT_TARGET=riscos
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"m68k-atari-mint")
ARTIFACT_TARGET=m68k-atari-mint
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"m5475-atari-mint")
ATARIARCH=v4e
ARTIFACT_TARGET=m5475-atari-mint
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"i686-w64-mingw32")
ARTIFACT_TARGET=windows
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"ppc-amigaos")
ARTIFACT_TARGET=amiga
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
esac
- IDENTIFIER="${BUILD}-${IDENTIFIER}"
- OLD_IDENTIFIER="${BUILD}-${OLD_IDENTIFIER}"
+ IDENTIFIER="${HOST}-${IDENTIFIER}"
+ OLD_IDENTIFIER="${HOST}-${OLD_IDENTIFIER}"
PKG_SRC=nsmonkey
PKG_SFX=
;;
@@ -329,7 +329,7 @@ case ${TARGET} in
esac
# setup environment
-export PREFIX=${JENKINS_HOME}/artifacts-${BUILD}
+export PREFIX=${JENKINS_HOME}/artifacts-${HOST}
export PKG_CONFIG_PATH=${PREFIX}/lib/pkgconfig
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${PREFIX}/lib
export PATH=${PATH}:${PREFIX}/bin
@@ -342,7 +342,7 @@ fi
# convert javascript parameters
if [ "${BUILD_JS}" = "json" ];then
- case ${BUILD} in
+ case ${HOST} in
"arm-unknown-riscos")
BUILD_MOZJS=NO
BUILD_JS=YES
-----------------------------------------------------------------------
Summary of changes:
Docs/env.sh | 48 +++++++++++++++++++-------
utils/jenkins-build.sh | 90 ++++++++++++++++++++++++------------------------
@@ -28,7 +28,7 @@
#
# TARGET is set to the frontend target to build
-# BUILD is set to the identifier of the toolchain doing the building
+# HOST is set to the identifier of the toolchain doing the building
# CC is the compiler (gcc or clang)
# BUILD_JS is the javascript type (json or jsoff)
2 files changed, 81 insertions(+), 57 deletions(-)
diff --git a/utils/jenkins-build.sh b/utils/jenkins-build.sh
index b4704c9..e7de93d 100755
--- a/utils/jenkins-build.sh
+++ b/utils/jenkins-build.sh
@@ -28,7 +28,7 @@
#
# TARGET is set to the frontend target to build
# BUILD is set to the identifier of the toolchain doing the building
# CC is the compiler (gcc or clang)
# BUILD_JS is the javascript type (json or jsoff)
# BUILD_NUMBER is the CI build number
@@ -56,13 +56,13 @@ MAKE=make
# specific parameters too
case ${TARGET} in
"riscos")
- case ${BUILD} in
+ case ${HOST} in
"arm-unknown-riscos")
ARTIFACT_TARGET=riscos
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -73,13 +73,13 @@ case ${TARGET} in
;;
"haiku")
- case ${BUILD} in
+ case ${HOST} in
"i586-pc-haiku")
ARTIFACT_TARGET=Haiku
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -91,13 +91,13 @@ case ${TARGET} in
"windows")
- case ${BUILD} in
+ case ${HOST} in
"i686-w64-mingw32")
ARTIFACT_TARGET=windows
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -109,11 +109,11 @@ case ${TARGET} in
"cocoa")
- case ${BUILD} in
+ case ${HOST} in
"i686-apple-darwin10")
ARTIFACT_TARGET=Darwin
- IDENTIFIER="${BUILD}-${IDENTIFIER}"
- OLD_IDENTIFIER="${BUILD}-${OLD_IDENTIFIER}"
+ IDENTIFIER="${HOST}-${IDENTIFIER}"
+ OLD_IDENTIFIER="${HOST}-${OLD_IDENTIFIER}"
;;
"powerpc-apple-darwin9")
@@ -123,7 +123,7 @@ case ${TARGET} in
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -135,13 +135,13 @@ case ${TARGET} in
"amiga")
- case ${BUILD} in
+ case ${HOST} in
"ppc-amigaos")
ARTIFACT_TARGET=amiga
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -153,7 +153,7 @@ case ${TARGET} in
"atari")
- case ${BUILD} in
+ case ${HOST} in
"m68k-atari-mint")
ARTIFACT_TARGET=m68k-atari-mint
PKG_SRC=ns020
@@ -170,7 +170,7 @@ case ${TARGET} in
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -182,7 +182,7 @@ case ${TARGET} in
"gtk")
- case ${BUILD} in
+ case ${HOST} in
"x86_64-linux-gnu")
ARTIFACT_TARGET=Linux
;;
@@ -193,7 +193,7 @@ case ${TARGET} in
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD}\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST}\""
exit 1
;;
@@ -205,7 +205,7 @@ case ${TARGET} in
"framebuffer")
- case ${BUILD} in
+ case ${HOST} in
"x86_64-linux-gnu")
ARTIFACT_TARGET=Linux
;;
@@ -220,37 +220,37 @@ case ${TARGET} in
"arm-unknown-riscos")
ARTIFACT_TARGET=riscos
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"m68k-atari-mint")
ARTIFACT_TARGET=m68k-atari-mint
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"m5475-atari-mint")
ATARIARCH=v4e
ARTIFACT_TARGET=m5475-atari-mint
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"i686-w64-mingw32")
ARTIFACT_TARGET=windows
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"ppc-amigaos")
ARTIFACT_TARGET=amiga
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
@@ -263,7 +263,7 @@ case ${TARGET} in
"monkey")
# monkey target can be built on most of the supported architectures
- case ${BUILD} in
+ case ${HOST} in
"x86_64-linux-gnu")
ARTIFACT_TARGET=Linux
;;
@@ -278,44 +278,44 @@ case ${TARGET} in
"arm-unknown-riscos")
ARTIFACT_TARGET=riscos
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"m68k-atari-mint")
ARTIFACT_TARGET=m68k-atari-mint
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"m5475-atari-mint")
ATARIARCH=v4e
ARTIFACT_TARGET=m5475-atari-mint
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"i686-w64-mingw32")
ARTIFACT_TARGET=windows
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
"ppc-amigaos")
ARTIFACT_TARGET=amiga
- export GCCSDK_INSTALL_ENV=/opt/netsurf/${BUILD}/env
- export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${BUILD}/cross/bin
+ export GCCSDK_INSTALL_ENV=/opt/netsurf/${HOST}/env
+ export GCCSDK_INSTALL_CROSSBIN=/opt/netsurf/${HOST}/cross/bin
;;
*)
- echo "Target \"${TARGET}\" cannot be built on \"${BUILD})\""
+ echo "Target \"${TARGET}\" cannot be built on \"${HOST})\""
exit 1
;;
esac
- IDENTIFIER="${BUILD}-${IDENTIFIER}"
- OLD_IDENTIFIER="${BUILD}-${OLD_IDENTIFIER}"
+ IDENTIFIER="${HOST}-${IDENTIFIER}"
+ OLD_IDENTIFIER="${HOST}-${OLD_IDENTIFIER}"
PKG_SRC=nsmonkey
PKG_SFX=
;;
@@ -329,7 +329,7 @@ case ${TARGET} in
esac
# setup environment
-export PREFIX=${JENKINS_HOME}/artifacts-${BUILD}
+export PREFIX=${JENKINS_HOME}/artifacts-${HOST}
export PKG_CONFIG_PATH=${PREFIX}/lib/pkgconfig
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${PREFIX}/lib
export PATH=${PATH}:${PREFIX}/bin
@@ -342,7 +342,7 @@ fi
# convert javascript parameters
if [ "${BUILD_JS}" = "json" ];then
- case ${BUILD} in
+ case ${HOST} in
"arm-unknown-riscos")
BUILD_MOZJS=NO
BUILD_JS=YES
@@ -28,7 +28,7 @@
#
# TARGET is set to the frontend target to build
-# BUILD is set to the identifier of the toolchain doing the building
+# HOST is set to the identifier of the toolchain doing the building
# CC is the compiler (gcc or clang)
# BUILD_JS is the javascript type (json or jsoff)
--
Document Object Model library
8 years, 5 months